@@ -96,7 +96,7 @@ VT_VALUE_SET_STORED_TYPE(char const *, std::string);
 VT_VALUE_SET_STORED_TYPE(char *, std::string);
 
 #ifdef PXR_PYTHON_SUPPORT_ENABLED
-VT_VALUE_SET_STORED_TYPE(boost::python::object, TfPyObjWrapper);
+VT_VALUE_SET_STORED_TYPE(pxr_boost::python::object, TfPyObjWrapper);
 #endif // PXR_PYTHON_SUPPORT_ENABLED
 
 #undef VT_VALUE_SET_STORED_TYPE
@@ -446,7 +446,7 @@ class VtValue
 #ifdef PXR_PYTHON_SUPPORT_ENABLED
             ProxiedType const &p = VtGetProxiedObject(obj);
             TfPyLock lock;
-            return boost::python::api::object(p);
+            return pxr_boost::python::api::object(p);
 #else
             return {};
 #endif //PXR_PYTHON_SUPPORT_ENABLED
@@ -507,7 +507,7 @@ class VtValue
 #ifdef PXR_PYTHON_SUPPORT_ENABLED
             VtValue const *val = VtGetErasedProxiedVtValue(obj);
             TfPyLock lock;
-            return boost::python::api::object(*val);
+            return pxr_boost::python::api::object(*val);
 #else
             return {};
 #endif //PXR_PYTHON_SUPPORT_ENABLED
@@ -856,7 +856,7 @@ public:
     /// Construct a VtValue holding a copy of \p obj.
     /// 
     /// If T is a char pointer or array, produce a VtValue holding a
-    /// std::string. If T is boost::python::object, produce a VtValue holding
+    /// std::string. If T is pxr_boost::python::object, produce a VtValue holding
     /// a TfPyObjWrapper.
     template <class T>
     explicit VtValue(T const &obj) {
@@ -1103,7 +1103,8 @@ public:
     template <class T>
     T const &UncheckedGet() const & { return _Get<T>(); }
 
-    /// \overload In case *this is an rvalue, move the held value out and return
+    /// \overload 
+    /// In case *this is an rvalue, move the held value out and return
     /// by value.
     template <class T>
     T UncheckedGet() && { return UncheckedRemove<T>(); }
@@ -1130,7 +1131,8 @@ public:
         return _Get<T>();
     }
 
-    /// \overload In case *this is an rvalue, move the held value out and return
+    /// \overload 
+    /// In case *this is an rvalue, move the held value out and return
     /// by value.
     template <class T>
     T Get() && {
@@ -1474,7 +1476,7 @@ ARCH_PRAGMA_POP
 
     // This grants friend access to a function in the wrapper file for this
     // class.  This lets the wrapper reach down into a value to get a
-    // boost::python wrapped object corresponding to the held type.  This
+    // pxr_boost::python wrapped object corresponding to the held type.  This
     // facility is necessary to get the python API we want.
     friend TfPyObjWrapper
     Vt_GetPythonObjectFromHeldValue(VtValue const &self);
