@@ -1,33 +1,21 @@
 //
 // Copyright 2018 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 
 #ifndef PXR_USD_NDR_FILESYSTEM_DISCOVERY_HELPERS_H
 #define PXR_USD_NDR_FILESYSTEM_DISCOVERY_HELPERS_H
 
 /// \file ndr/filesystemDiscoveryHelpers.h
+///
+/// \deprecated
+/// All Ndr objects are deprecated in favor of the corresponding Sdr objects
+/// in sdr/filesystemDiscoveryHelpers.h
 
 #include "pxr/pxr.h"
+#include "pxr/base/tf/envSetting.h"
 #include "pxr/usd/ndr/api.h"
 #include "pxr/usd/ndr/declare.h"
 #include "pxr/usd/ndr/nodeDiscoveryResult.h"
@@ -45,6 +33,18 @@ class NdrDiscoveryPluginContext;
 /// in a large chunk of the functionality.
 ///
 
+/// \deprecated in favor of PXR_SDR_FS_PLUGIN_SEARCH_PATHS
+NDR_API
+extern TfEnvSetting<std::string> PXR_NDR_FS_PLUGIN_SEARCH_PATHS;
+
+/// \deprecated in favor of PXR_SDR_FS_PLUGIN_SEARCH_PATHS
+NDR_API
+extern TfEnvSetting<std::string> PXR_NDR_FS_PLUGIN_ALLOWED_EXTS;
+
+/// \deprecated in favor of PXR_NDR_FS_PLUGIN_FOLLOW_SYMLINKS
+NDR_API
+extern TfEnvSetting<bool> PXR_NDR_FS_PLUGIN_FOLLOW_SYMLINKS;
+
 /// Type of a function that can be used to parse a discovery result's identifier
 /// into its family, name, and version.
 using NdrParseIdentifierFn = std::function<
@@ -70,6 +70,9 @@ using NdrParseIdentifierFn = std::function<
 /// 
 /// \note The python version of this function returns a tuple containing
 /// (famiyName, implementationName, version).
+///
+/// \deprecated
+/// Deprecated in favor of SdrFsHelpersSplitShaderIdentifier
 NDR_API 
 bool
 NdrFsHelpersSplitShaderIdentifier(
@@ -96,6 +99,9 @@ NdrFsHelpersSplitShaderIdentifier(
 /// invalid and not added as a discovery result. Note that the version for 
 /// every discovery result returned by this function will be naively marked as 
 /// being default even if multiple versions with the same name are found.
+///
+/// \deprecated
+/// Deprecated in favor of SdrFsHelpersDiscoverShaderNodes
 NDR_API
 NdrNodeDiscoveryResultVec
 NdrFsHelpersDiscoverNodes(
@@ -109,6 +115,9 @@ NdrFsHelpersDiscoverNodes(
 
 /// Struct for holding a URI and its resolved URI for a file discovered
 /// by NdrFsHelpersDiscoverFiles
+///
+/// \deprecated
+/// Deprecated in favor of SdrDiscoveryUri
 struct NdrDiscoveryUri 
 {
     std::string uri;
@@ -129,6 +138,9 @@ using NdrDiscoveryUriVec = std::vector<NdrDiscoveryUri>;
 /// This is an alternative to NdrFsHelpersDiscoverNodes for discovery plugins 
 /// that want to search for files that are not meant to be returned by discovery
 /// themselves, but can be parsed to generate the discovery results.
+///
+/// \deprecated
+/// Deprecated in favor of SdrFsHelpersDiscoverFiles
 NDR_API
 NdrDiscoveryUriVec
 NdrFsHelpersDiscoverFiles(
