@@ -63,6 +63,7 @@ TF_DECLARE_REF_PTRS(HdsiLegacyDisplayStyleOverrideSceneIndex);
 TF_DECLARE_REF_PTRS(HdsiPrimTypePruningSceneIndex);
 TF_DECLARE_REF_PTRS(HdsiSceneGlobalsSceneIndex);
 TF_DECLARE_REF_PTRS(HdSceneIndexBase);
+TF_DECLARE_REF_PTRS(HdxTaskControllerSceneIndex);
 
 using UsdStageWeakPtr = TfWeakPtr<class UsdStage>;
 
@@ -379,7 +380,7 @@ public:
         IntersectionResultVector* outResults);
 
     /// Decodes a pick result given hydra prim ID/instance ID (like you'd get
-    /// from an ID render).
+    /// from an ID render), where ID is represented as a vec4 color.
     USDIMAGINGGL_API
     bool DecodeIntersection(
         unsigned char const primIdColor[4],
@@ -389,6 +390,17 @@ public:
         int *outHitInstanceIndex = NULL,
         HdInstancerContext *outInstancerContext = NULL);
 
+    /// Decodes a pick result given hydra prim ID/instance ID (like you'd get
+    /// from an ID render), where ID is represented as a int.
+    USDIMAGINGGL_API
+    bool DecodeIntersection(
+        int primIdx,
+        int instanceIdx,
+        SdfPath *outHitPrimPath = NULL,
+        SdfPath *outHitInstancerPath = NULL,
+        int *outHitInstanceIndex = NULL,
+        HdInstancerContext *outInstancerContext = NULL);
+
     /// @}
     
     // ---------------------------------------------------------------------
@@ -400,10 +412,16 @@ public:
     USDIMAGINGGL_API
     static TfTokenVector GetRendererPlugins();
 
-    /// Return the user-friendly description of a renderer plugin.
+    /// Return the user-friendly name of a renderer plugin.
     USDIMAGINGGL_API
     static std::string GetRendererDisplayName(TfToken const &id);
 
+    /// Return the user-friendly name of the Hgi implementation.
+    /// For example: OpenGL, Metal, Vulkan. This is only available
+    /// if a render plugin was set and it uses Hgi.
+    USDIMAGINGGL_API
+    std::string GetRendererHgiDisplayName() const;
+
     /// Return if the GPU is enabled and can be used for any rendering tasks.
     USDIMAGINGGL_API
     bool GetGPUEnabled() const;
@@ -432,6 +450,10 @@ public:
     USDIMAGINGGL_API
     bool SetRendererAov(TfToken const& id);
 
+    /// Set the current renderer AOVs to a list of \p ids.
+    USDIMAGINGGL_API
+    bool SetRendererAovs(TfTokenVector const &ids);
+
     /// Returns an AOV texture handle for the given token.
     USDIMAGINGGL_API
     HgiTextureHandle GetAovTexture(TfToken const& name) const;
@@ -648,9 +670,15 @@ protected:
     USDIMAGINGGL_API
     HdRenderIndex *_GetRenderIndex() const;
 
+    /// \deprecated.
+    /// Use _Execute(const UsdImaginGLRenderParams &, const SdfPathVector &).
     USDIMAGINGGL_API
     void _Execute(const UsdImagingGLRenderParams &params,
-                  HdTaskSharedPtrVector tasks);
+                  const HdTaskSharedPtrVector tasks);
+
+    USDIMAGINGGL_API
+    void _Execute(const UsdImagingGLRenderParams &params,
+                  const SdfPathVector &taskPaths);
 
     USDIMAGINGGL_API
     bool _CanPrepare(const UsdPrim& root);
@@ -746,6 +774,7 @@ protected:
     SdfPath const _sceneDelegateId;
 
     std::unique_ptr<HdxTaskController> _taskController;
+    HdxTaskControllerSceneIndexRefPtr _taskControllerSceneIndex;
 
     HdxSelectionTrackerSharedPtr _selTracker;
     HdRprimCollection _renderCollection;
