@@ -808,6 +808,10 @@ class StageView(QGLWidget):
     def rendererDisplayName(self):
         return self._rendererDisplayName
 
+    @property
+    def rendererHgiDisplayName(self):
+        return self._rendererHgiDisplayName
+
     @property
     def rendererAovName(self):
         return self._rendererAovName
@@ -872,7 +876,7 @@ class StageView(QGLWidget):
         # prep HUD regions
         self._hud = HUD()
         self._hud.addGroup("TopLeft",     250, 160)  # subtree
-        self._hud.addGroup("TopRight",    140, 32)   # Hydra: Enabled
+        self._hud.addGroup("TopRight",    140, 48)   # Hydra: Enabled
         self._hud.addGroup("BottomLeft",  250, 160)  # GPU stats
         self._hud.addGroup("BottomRight", 210, 32)   # Camera, Complexity
 
@@ -940,6 +944,14 @@ class StageView(QGLWidget):
         self._allowAsync = False
         self._bboxstandin = False
 
+        # The original window size before scaling.
+        # Due to rounding errors, this might be different
+        # from self.size() * self.devicePixelRatioF().
+        # If not set, then computed from the device-independent
+        # window size and device pixel ratio as shown above.
+        # Use GetPhysicalWindowSize() to get the correct value.
+        self._physicalWindowSize = None
+
         # Update all properties for the current stage.
         self._stageReplaced()
 
@@ -962,6 +974,8 @@ class StageView(QGLWidget):
 
     def _handleRendererChanged(self, rendererId):
         self._rendererDisplayName = self.GetRendererDisplayName(rendererId)
+        self._rendererHgiDisplayName = (
+            self.GetRendererHgiDisplayName())
         self._rendererAovName = "color"
         self._renderPauseState = False
         self._renderStopState = False
@@ -990,6 +1004,12 @@ class StageView(QGLWidget):
         else:
             return ""
 
+    def GetRendererHgiDisplayName(self):
+        if self._renderer:
+            return self._renderer.GetRendererHgiDisplayName()
+        else:
+            return ""
+
     def GetCurrentRendererId(self):
         if self._renderer:
             return self._renderer.GetCurrentRendererId()
@@ -1452,8 +1472,7 @@ class StageView(QGLWidget):
                if self._dataModel.viewSettings.cullBackfaces
                else UsdImagingGL.CullStyle.CULL_STYLE_NOTHING)
         self._renderParams.gammaCorrectColors = False
-        self._renderParams.enableIdRender = self._dataModel.viewSettings.displayPrimId
-        self._renderParams.enableSampleAlphaToCoverage = not self._dataModel.viewSettings.displayPrimId
+        self._renderParams.enableSamlpeAlphaToCoverage = True
         self._renderParams.highlight = renderSelHighlights
         self._renderParams.enableSceneMaterials = self._dataModel.viewSettings.enableSceneMaterials
         self._renderParams.domeLightCameraVisibility = self._dataModel.viewSettings.domeLightTexturesVisible
@@ -1531,9 +1550,7 @@ class StageView(QGLWidget):
         
         if self.hasLockedAspectRatio():
             if self._cropImageToCameraViewport:
-                targetAspect = (
-                    float(self.size().width()) / max(1.0, self.size().height()))
-
+                targetAspect = self.aspectRatio()
                 if targetAspect < cameraAspectRatio:
                     windowPolicy =  CameraUtil.MatchHorizontally
             else:
@@ -1541,13 +1558,27 @@ class StageView(QGLWidget):
                     windowPolicy =  CameraUtil.Fit
         
         return windowPolicy
-    
-    def computeWindowSize(self):
+
+    def SetPhysicalWindowSize(self, width, height):
+        self._physicalWindowSize = (width, height)
+        # Round up so we can always crop out a pixel in each dimension
+        # from the framebuffer to get the exact physical size.
+        ratio = self.devicePixelRatioF()
+        self.setFixedSize(ceil(width / ratio), ceil(height / ratio))
+
+    def GetPhysicalWindowSize(self):
+        if self._physicalWindowSize:
+            return self._physicalWindowSize
+
         size = self.size() * self.devicePixelRatioF()
-        return (int(size.width()), int(size.height()))
+        return size.width(), size.height()
+
+    def aspectRatio(self):
+        width, height = self.GetPhysicalWindowSize()
+        return float(width) / max(1.0, height)
 
     def computeWindowViewport(self):
-        return (0, 0) + self.computeWindowSize()
+        return (0, 0) + self.GetPhysicalWindowSize()
 
     def resolveCamera(self):
         """Returns a tuple of the camera to use for rendering (either a scene
@@ -1575,7 +1606,7 @@ class StageView(QGLWidget):
 
         # Conform the camera's frustum to the window viewport, if necessary.
         if not self._cropImageToCameraViewport:
-            targetAspect = float(self.size().width()) / max(1.0, self.size().height())
+            targetAspect = self.aspectRatio()
             if self._fitCameraInViewport:
                 CameraUtil.ConformWindow(gfCam, CameraUtil.Fit, targetAspect)
             else:
@@ -1594,13 +1625,12 @@ class StageView(QGLWidget):
         # Conform the camera viewport to the camera's aspect ratio,
         # and center the camera viewport in the window viewport.
         windowPolicy = CameraUtil.MatchVertically
-        targetAspect = (
-          float(self.size().width()) / max(1.0, self.size().height()))
+        targetAspect = self.aspectRatio()
         if targetAspect < cameraAspectRatio:
             windowPolicy = CameraUtil.MatchHorizontally
 
         viewport = Gf.Range2d(Gf.Vec2d(0, 0),
-                              Gf.Vec2d(self.computeWindowSize()))
+                              Gf.Vec2d(self.GetPhysicalWindowSize()))
         viewport = CameraUtil.ConformedWindow(viewport, windowPolicy, cameraAspectRatio)
 
         viewport = (viewport.GetMin()[0], viewport.GetMin()[1],
@@ -1684,7 +1714,7 @@ class StageView(QGLWidget):
             if self._cropImageToCameraViewport:
                 viewport = cameraViewport
 
-            renderBufferSize = Gf.Vec2i(self.computeWindowSize())
+            renderBufferSize = Gf.Vec2i(self.GetPhysicalWindowSize())
 
             renderer.SetRenderBufferSize(
                 renderBufferSize)
@@ -1907,7 +1937,10 @@ class StageView(QGLWidget):
             toPrint = {"Hydra": "(stopped)"}
         else:
             toPrint = {"Hydra": self._rendererDisplayName}
-            
+
+        if self._rendererHgiDisplayName:
+            toPrint["  Hgi"] = self._rendererHgiDisplayName
+
         if self._rendererAovName != "color":
             toPrint["  AOV"] = self._rendererAovName
         self._hud.updateGroup("TopRight", self.width()-160, 14, col,
@@ -2089,7 +2122,7 @@ class StageView(QGLWidget):
                     freeCam.AdjustDistance(1 + zoomDelta)
 
             elif self._cameraMode == "truck":
-                height = float(self.size().height())
+                height = float(self.GetPhysicalWindowSize()[1])
                 pixelsToWorld = freeCam.ComputePixelsToWorldFactor(height)
 
                 self._dataModel.viewSettings.freeCamera.Truck(
@@ -2199,7 +2232,6 @@ class StageView(QGLWidget):
                    if self._dataModel.viewSettings.cullBackfaces
                    else UsdImagingGL.CullStyle.CULL_STYLE_NOTHING)
         self._renderParams.gammaCorrectColors = False
-        self._renderParams.enableIdRender = True
         self._renderParams.enableSampleAlphaToCoverage = False
         self._renderParams.enableSceneMaterials = self._dataModel.viewSettings.enableSceneMaterials
         self._renderParams.enableSceneLights = self._dataModel.viewSettings.enableSceneLights
